Class: PulpDebClient::ContentInstallerFileIndicesApi
- Inherits:
-
Object
- Object
- PulpDebClient::ContentInstallerFileIndicesApi
- Defined in:
- lib/pulp_deb_client/api/content_installer_file_indices_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(deb_installer_file_index, opts = {}) ⇒ DebInstallerFileIndexResponse
Create an installer file index An InstallerFileIndex represents the indices for a set of installer files.
-
#create_with_http_info(deb_installer_file_index, opts = {}) ⇒ Array<(DebInstallerFileIndexResponse, Integer, Hash)>
Create an installer file index An InstallerFileIndex represents the indices for a set of installer files.
-
#initialize(api_client = ApiClient.default) ⇒ ContentInstallerFileIndicesApi
constructor
A new instance of ContentInstallerFileIndicesApi.
-
#list(opts = {}) ⇒ PaginateddebInstallerFileIndexResponseList
List InstallerFileIndices An InstallerFileIndex represents the indices for a set of installer files.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebInstallerFileIndexResponseList, Integer, Hash)>
List InstallerFileIndices An InstallerFileIndex represents the indices for a set of installer files.
-
#read(deb_installer_file_index_href, opts = {}) ⇒ DebInstallerFileIndexResponse
Inspect an installer file index An InstallerFileIndex represents the indices for a set of installer files.
-
#read_with_http_info(deb_installer_file_index_href, opts = {}) ⇒ Array<(DebInstallerFileIndexResponse, Integer, Hash)>
Inspect an installer file index An InstallerFileIndex represents the indices for a set of installer files.
-
#set_label(deb_installer_file_index_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(deb_installer_file_index_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#unset_label(deb_installer_file_index_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(deb_installer_file_index_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentInstallerFileIndicesApi
Returns a new instance of ContentInstallerFileIndicesApi.
19 20 21 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(deb_installer_file_index, opts = {}) ⇒ DebInstallerFileIndexResponse
Create an installer file index An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one ‘SHA256SUMS’ and/or ‘MD5SUMS’ file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
27 28 29 30 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 27 def create(deb_installer_file_index, opts = {}) data, _status_code, _headers = create_with_http_info(deb_installer_file_index, opts) data end |
#create_with_http_info(deb_installer_file_index, opts = {}) ⇒ Array<(DebInstallerFileIndexResponse, Integer, Hash)>
Create an installer file index An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 37 def create_with_http_info(deb_installer_file_index, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentInstallerFileIndicesApi.create ...' end # verify the required parameter 'deb_installer_file_index' is set if @api_client.config.client_side_validation && deb_installer_file_index.nil? fail ArgumentError, "Missing the required parameter 'deb_installer_file_index' when calling ContentInstallerFileIndicesApi.create" end # resource path local_var_path = '/pulp/api/v3/content/deb/installer_file_indices/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(deb_installer_file_index) # return_type return_type = opts[:debug_return_type] || 'DebInstallerFileIndexResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentInstallerFileIndicesApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentInstallerFileIndicesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebInstallerFileIndexResponseList
List InstallerFileIndices An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one ‘SHA256SUMS’ and/or ‘MD5SUMS’ file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
112 113 114 115 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 112 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebInstallerFileIndexResponseList, Integer, Hash)>
List InstallerFileIndices An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 139 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentInstallerFileIndicesApi.list ...' end allowable_values = ["-architecture", "-component", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-relative_path", "-sha256", "-timestamp_of_interest", "-upstream_id", "architecture", "component", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "relative_path", "sha256", "timestamp_of_interest", "upstream_id"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/deb/installer_file_indices/' # query parameters query_params = opts[:query_params] || {} query_params[:'architecture'] = opts[:'architecture'] if !opts[:'architecture'].nil? query_params[:'component'] = opts[:'component'] if !opts[:'component'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'sha256'] = opts[:'sha256'] if !opts[:'sha256'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginateddebInstallerFileIndexResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentInstallerFileIndicesApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentInstallerFileIndicesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_installer_file_index_href, opts = {}) ⇒ DebInstallerFileIndexResponse
Inspect an installer file index An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one ‘SHA256SUMS’ and/or ‘MD5SUMS’ file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
212 213 214 215 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 212 def read(deb_installer_file_index_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_installer_file_index_href, opts) data end |
#read_with_http_info(deb_installer_file_index_href, opts = {}) ⇒ Array<(DebInstallerFileIndexResponse, Integer, Hash)>
Inspect an installer file index An InstallerFileIndex represents the indices for a set of installer files. Associated artifacts: Exactly one 'SHA256SUMS' and/or 'MD5SUMS' file. Each InstallerFileIndes is associated with a single component-architecture combination within a single Release. Note that installer files are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) does not make use of installer content.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 224 def read_with_http_info(deb_installer_file_index_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentInstallerFileIndicesApi.read ...' end # verify the required parameter 'deb_installer_file_index_href' is set if @api_client.config.client_side_validation && deb_installer_file_index_href.nil? fail ArgumentError, "Missing the required parameter 'deb_installer_file_index_href' when calling ContentInstallerFileIndicesApi.read" end # resource path local_var_path = '{deb_installer_file_index_href}'.sub('{' + 'deb_installer_file_index_href' + '}', CGI.escape(deb_installer_file_index_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DebInstallerFileIndexResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentInstallerFileIndicesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentInstallerFileIndicesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(deb_installer_file_index_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
280 281 282 283 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 280 def set_label(deb_installer_file_index_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(deb_installer_file_index_href, set_label, opts) data end |
#set_label_with_http_info(deb_installer_file_index_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 291 def set_label_with_http_info(deb_installer_file_index_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentInstallerFileIndicesApi.set_label ...' end # verify the required parameter 'deb_installer_file_index_href' is set if @api_client.config.client_side_validation && deb_installer_file_index_href.nil? fail ArgumentError, "Missing the required parameter 'deb_installer_file_index_href' when calling ContentInstallerFileIndicesApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling ContentInstallerFileIndicesApi.set_label" end # resource path local_var_path = '{deb_installer_file_index_href}set_label/'.sub('{' + 'deb_installer_file_index_href' + '}', CGI.escape(deb_installer_file_index_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:debug_return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentInstallerFileIndicesApi.set_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentInstallerFileIndicesApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(deb_installer_file_index_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
354 355 356 357 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 354 def unset_label(deb_installer_file_index_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(deb_installer_file_index_href, unset_label, opts) data end |
#unset_label_with_http_info(deb_installer_file_index_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/pulp_deb_client/api/content_installer_file_indices_api.rb', line 365 def unset_label_with_http_info(deb_installer_file_index_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentInstallerFileIndicesApi.unset_label ...' end # verify the required parameter 'deb_installer_file_index_href' is set if @api_client.config.client_side_validation && deb_installer_file_index_href.nil? fail ArgumentError, "Missing the required parameter 'deb_installer_file_index_href' when calling ContentInstallerFileIndicesApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling ContentInstallerFileIndicesApi.unset_label" end # resource path local_var_path = '{deb_installer_file_index_href}unset_label/'.sub('{' + 'deb_installer_file_index_href' + '}', CGI.escape(deb_installer_file_index_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:debug_return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentInstallerFileIndicesApi.unset_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentInstallerFileIndicesApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |