Class: PulpDebClient::ContentPackagesApi
- Inherits:
-
Object
- Object
- PulpDebClient::ContentPackagesApi
- Defined in:
- lib/pulp_deb_client/api/content_packages_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(opts = {}) ⇒ AsyncOperationResponse
Create a package Trigger an asynchronous task to create content,optionally create new repository version.
-
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a package Trigger an asynchronous task to create content,optionally create new repository version.
-
#initialize(api_client = ApiClient.default) ⇒ ContentPackagesApi
constructor
A new instance of ContentPackagesApi.
-
#list(opts = {}) ⇒ PaginateddebPackageResponseList
List packages A Package represents a ‘.deb’ binary package.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebPackageResponseList, Integer, Hash)>
List packages A Package represents a '.deb' binary package.
-
#read(deb_package_href, opts = {}) ⇒ DebPackageResponse
Inspect a package A Package represents a ‘.deb’ binary package.
-
#read_with_http_info(deb_package_href, opts = {}) ⇒ Array<(DebPackageResponse, Integer, Hash)>
Inspect a package A Package represents a '.deb' binary package.
-
#set_label(deb_package_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(deb_package_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#unset_label(deb_package_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(deb_package_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentPackagesApi
Returns a new instance of ContentPackagesApi.
19 20 21 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(opts = {}) ⇒ AsyncOperationResponse
Create a package Trigger an asynchronous task to create content,optionally create new repository version.
35 36 37 38 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 35 def create(opts = {}) data, _status_code, _headers = create_with_http_info(opts) data end |
#create_with_http_info(opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a package Trigger an asynchronous task to create content,optionally create new repository version.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 53 def create_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.create ...' end if @api_client.config.client_side_validation && !opts[:'relative_path'].nil? && opts[:'relative_path'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"relative_path"]" when calling ContentPackagesApi.create, the character length must be great than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentPackagesApi.create, the character length must be great than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'distribution'].nil? && opts[:'distribution'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"distribution"]" when calling ContentPackagesApi.create, the character length must be great than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'component'].nil? && opts[:'component'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"component"]" when calling ContentPackagesApi.create, the character length must be great than or equal to 1.' end # resource path local_var_path = '/pulp/api/v3/content/deb/packages/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil? form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil? form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil? form_params['relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil? form_params['file'] = opts[:'file'] if !opts[:'file'].nil? form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil? form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil? form_params['distribution'] = opts[:'distribution'] if !opts[:'distribution'].nil? form_params['component'] = opts[:'component'] if !opts[:'component'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebPackageResponseList
List packages A Package represents a ‘.deb’ binary package. Associated artifacts: Exactly one ‘.deb’ package file.
173 174 175 176 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 173 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebPackageResponseList, Integer, Hash)>
List packages A Package represents a '.deb' binary package. Associated artifacts: Exactly one '.deb' package file.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 224 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.list ...' end allowable_values = ["allowed", "foreign", "no", "same"] if @api_client.config.client_side_validation && opts[:'multi_arch'] && !allowable_values.include?(opts[:'multi_arch']) fail ArgumentError, "invalid value for \"multi_arch\", must be one of #{allowable_values}" end allowable_values = ["-architecture", "-auto_built_package", "-breaks", "-bugs", "-build_essential", "-built_using", "-conflicts", "-custom_fields", "-depends", "-description", "-description_md5", "-enhances", "-essential", "-homepage", "-installed_size", "-maintainer", "-multi_arch", "-origin", "-original_maintainer", "-package", "-pk", "-pre_depends", "-priority", "-provides", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-recommends", "-relative_path", "-replaces", "-section", "-sha256", "-source", "-suggests", "-tag", "-timestamp_of_interest", "-upstream_id", "-version", "architecture", "auto_built_package", "breaks", "bugs", "build_essential", "built_using", "conflicts", "custom_fields", "depends", "description", "description_md5", "enhances", "essential", "homepage", "installed_size", "maintainer", "multi_arch", "origin", "original_maintainer", "package", "pk", "pre_depends", "priority", "provides", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "recommends", "relative_path", "replaces", "section", "sha256", "source", "suggests", "tag", "timestamp_of_interest", "upstream_id", "version"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/deb/packages/' # query parameters query_params = opts[:query_params] || {} query_params[:'architecture'] = opts[:'architecture'] if !opts[:'architecture'].nil? query_params[:'auto_built_package'] = opts[:'auto_built_package'] if !opts[:'auto_built_package'].nil? query_params[:'build_essential'] = opts[:'build_essential'] if !opts[:'build_essential'].nil? query_params[:'built_using'] = opts[:'built_using'] if !opts[:'built_using'].nil? query_params[:'essential'] = opts[:'essential'] if !opts[:'essential'].nil? query_params[:'installed_size'] = opts[:'installed_size'] if !opts[:'installed_size'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'maintainer'] = opts[:'maintainer'] if !opts[:'maintainer'].nil? query_params[:'multi_arch'] = opts[:'multi_arch'] if !opts[:'multi_arch'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'origin'] = opts[:'origin'] if !opts[:'origin'].nil? query_params[:'original_maintainer'] = opts[:'original_maintainer'] if !opts[:'original_maintainer'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'package'] = opts[:'package'] if !opts[:'package'].nil? query_params[:'package__contains'] = opts[:'package__contains'] if !opts[:'package__contains'].nil? query_params[:'package__icontains'] = opts[:'package__icontains'] if !opts[:'package__icontains'].nil? query_params[:'package__iexact'] = opts[:'package__iexact'] if !opts[:'package__iexact'].nil? query_params[:'package__in'] = @api_client.build_collection_param(opts[:'package__in'], :csv) if !opts[:'package__in'].nil? query_params[:'package__iregex'] = opts[:'package__iregex'] if !opts[:'package__iregex'].nil? query_params[:'package__istartswith'] = opts[:'package__istartswith'] if !opts[:'package__istartswith'].nil? query_params[:'package__regex'] = opts[:'package__regex'] if !opts[:'package__regex'].nil? query_params[:'package__startswith'] = opts[:'package__startswith'] if !opts[:'package__startswith'].nil? query_params[:'priority'] = opts[:'priority'] if !opts[:'priority'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil? query_params[:'release'] = opts[:'release'] if !opts[:'release'].nil? query_params[:'release_component'] = opts[:'release_component'] if !opts[:'release_component'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'section'] = opts[:'section'] if !opts[:'section'].nil? query_params[:'sha256'] = opts[:'sha256'] if !opts[:'sha256'].nil? query_params[:'source'] = opts[:'source'] if !opts[:'source'].nil? query_params[:'tag'] = opts[:'tag'] if !opts[:'tag'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginateddebPackageResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_package_href, opts = {}) ⇒ DebPackageResponse
Inspect a package A Package represents a ‘.deb’ binary package. Associated artifacts: Exactly one ‘.deb’ package file.
325 326 327 328 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 325 def read(deb_package_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_package_href, opts) data end |
#read_with_http_info(deb_package_href, opts = {}) ⇒ Array<(DebPackageResponse, Integer, Hash)>
Inspect a package A Package represents a '.deb' binary package. Associated artifacts: Exactly one '.deb' package file.
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 337 def read_with_http_info(deb_package_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.read ...' end # verify the required parameter 'deb_package_href' is set if @api_client.config.client_side_validation && deb_package_href.nil? fail ArgumentError, "Missing the required parameter 'deb_package_href' when calling ContentPackagesApi.read" end # resource path local_var_path = '{deb_package_href}'.sub('{' + 'deb_package_href' + '}', CGI.escape(deb_package_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DebPackageResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(deb_package_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
393 394 395 396 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 393 def set_label(deb_package_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(deb_package_href, set_label, opts) data end |
#set_label_with_http_info(deb_package_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 404 def set_label_with_http_info(deb_package_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.set_label ...' end # verify the required parameter 'deb_package_href' is set if @api_client.config.client_side_validation && deb_package_href.nil? fail ArgumentError, "Missing the required parameter 'deb_package_href' when calling ContentPackagesApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling ContentPackagesApi.set_label" end # resource path local_var_path = '{deb_package_href}set_label/'.sub('{' + 'deb_package_href' + '}', CGI.escape(deb_package_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:debug_return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.set_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(deb_package_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
467 468 469 470 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 467 def unset_label(deb_package_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(deb_package_href, unset_label, opts) data end |
#unset_label_with_http_info(deb_package_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/pulp_deb_client/api/content_packages_api.rb', line 478 def unset_label_with_http_info(deb_package_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentPackagesApi.unset_label ...' end # verify the required parameter 'deb_package_href' is set if @api_client.config.client_side_validation && deb_package_href.nil? fail ArgumentError, "Missing the required parameter 'deb_package_href' when calling ContentPackagesApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling ContentPackagesApi.unset_label" end # resource path local_var_path = '{deb_package_href}unset_label/'.sub('{' + 'deb_package_href' + '}', CGI.escape(deb_package_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:debug_return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentPackagesApi.unset_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentPackagesApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |