Class: PulpDebClient::ContentReleaseFilesApi
- Inherits:
-
Object
- Object
- PulpDebClient::ContentReleaseFilesApi
- Defined in:
- lib/pulp_deb_client/api/content_release_files_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(deb_release_file, opts = {}) ⇒ DebReleaseFileResponse
Create a release file A ReleaseFile represents the Release file(s) from a single APT distribution.
-
#create_with_http_info(deb_release_file, opts = {}) ⇒ Array<(DebReleaseFileResponse, Integer, Hash)>
Create a release file A ReleaseFile represents the Release file(s) from a single APT distribution.
-
#initialize(api_client = ApiClient.default) ⇒ ContentReleaseFilesApi
constructor
A new instance of ContentReleaseFilesApi.
-
#list(opts = {}) ⇒ PaginateddebReleaseFileResponseList
List release files A ReleaseFile represents the Release file(s) from a single APT distribution.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebReleaseFileResponseList, Integer, Hash)>
List release files A ReleaseFile represents the Release file(s) from a single APT distribution.
-
#read(deb_release_file_href, opts = {}) ⇒ DebReleaseFileResponse
Inspect a release file A ReleaseFile represents the Release file(s) from a single APT distribution.
-
#read_with_http_info(deb_release_file_href, opts = {}) ⇒ Array<(DebReleaseFileResponse, Integer, Hash)>
Inspect a release file A ReleaseFile represents the Release file(s) from a single APT distribution.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentReleaseFilesApi
Returns a new instance of ContentReleaseFilesApi.
19 20 21 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(deb_release_file, opts = {}) ⇒ DebReleaseFileResponse
Create a release file A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of ‘Release’ and ‘InRelease’ file. If the ‘Release’ file is present, then there may also be a ‘Release.gpg’ detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Release’ files it needs when creating the publication. It does not make use of ReleaseFile content.
27 28 29 30 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 27 def create(deb_release_file, opts = {}) data, _status_code, _headers = create_with_http_info(deb_release_file, opts) data end |
#create_with_http_info(deb_release_file, opts = {}) ⇒ Array<(DebReleaseFileResponse, Integer, Hash)>
Create a release file A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of 'Release' and 'InRelease' file. If the 'Release' file is present, then there may also be a 'Release.gpg' detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Release' files it needs when creating the publication. It does not make use of ReleaseFile content.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 37 def create_with_http_info(deb_release_file, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleaseFilesApi.create ...' end # verify the required parameter 'deb_release_file' is set if @api_client.config.client_side_validation && deb_release_file.nil? fail ArgumentError, "Missing the required parameter 'deb_release_file' when calling ContentReleaseFilesApi.create" end # resource path local_var_path = '/pulp/api/v3/content/deb/release_files/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(deb_release_file) # return_type return_type = opts[:debug_return_type] || 'DebReleaseFileResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleaseFilesApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleaseFilesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebReleaseFileResponseList
List release files A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of ‘Release’ and ‘InRelease’ file. If the ‘Release’ file is present, then there may also be a ‘Release.gpg’ detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Release’ files it needs when creating the publication. It does not make use of ReleaseFile content.
111 112 113 114 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 111 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebReleaseFileResponseList, Integer, Hash)>
List release files A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of 'Release' and 'InRelease' file. If the 'Release' file is present, then there may also be a 'Release.gpg' detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Release' files it needs when creating the publication. It does not make use of ReleaseFile content.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 137 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleaseFilesApi.list ...' end allowable_values = ["-architectures", "-artifact_set_sha256", "-codename", "-components", "-distribution", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-pulp_type", "-relative_path", "-sha256", "-suite", "-timestamp_of_interest", "-upstream_id", "architectures", "artifact_set_sha256", "codename", "components", "distribution", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "pulp_type", "relative_path", "sha256", "suite", "timestamp_of_interest", "upstream_id"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/deb/release_files/' # query parameters query_params = opts[:query_params] || {} query_params[:'codename'] = opts[:'codename'] if !opts[:'codename'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'sha256'] = opts[:'sha256'] if !opts[:'sha256'].nil? query_params[:'suite'] = opts[:'suite'] if !opts[:'suite'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginateddebReleaseFileResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleaseFilesApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleaseFilesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_release_file_href, opts = {}) ⇒ DebReleaseFileResponse
Inspect a release file A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of ‘Release’ and ‘InRelease’ file. If the ‘Release’ file is present, then there may also be a ‘Release.gpg’ detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Release’ files it needs when creating the publication. It does not make use of ReleaseFile content.
209 210 211 212 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 209 def read(deb_release_file_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_release_file_href, opts) data end |
#read_with_http_info(deb_release_file_href, opts = {}) ⇒ Array<(DebReleaseFileResponse, Integer, Hash)>
Inspect a release file A ReleaseFile represents the Release file(s) from a single APT distribution. Associated artifacts: At least one of 'Release' and 'InRelease' file. If the 'Release' file is present, then there may also be a 'Release.gpg' detached signature file for it. Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Release' files it needs when creating the publication. It does not make use of ReleaseFile content.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/pulp_deb_client/api/content_release_files_api.rb', line 221 def read_with_http_info(deb_release_file_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleaseFilesApi.read ...' end # verify the required parameter 'deb_release_file_href' is set if @api_client.config.client_side_validation && deb_release_file_href.nil? fail ArgumentError, "Missing the required parameter 'deb_release_file_href' when calling ContentReleaseFilesApi.read" end # resource path local_var_path = '{deb_release_file_href}'.sub('{' + 'deb_release_file_href' + '}', CGI.escape(deb_release_file_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DebReleaseFileResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleaseFilesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleaseFilesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |