Class: PulpDebClient::ContentReleasesApi
- Inherits:
-
Object
- Object
- PulpDebClient::ContentReleasesApi
- Defined in:
- lib/pulp_deb_client/api/content_releases_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(deb_release, opts = {}) ⇒ AsyncOperationResponse
Create a release Trigger an asynchronous task to create content,optionally create new repository version.
-
#create_with_http_info(deb_release, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a release Trigger an asynchronous task to create content,optionally create new repository version.
-
#initialize(api_client = ApiClient.default) ⇒ ContentReleasesApi
constructor
A new instance of ContentReleasesApi.
-
#list(opts = {}) ⇒ PaginateddebReleaseResponseList
List releases The Release contains release file fields, that are not relevant to the APT repo structure.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebReleaseResponseList, Integer, Hash)>
List releases The Release contains release file fields, that are not relevant to the APT repo structure.
-
#read(deb_release_href, opts = {}) ⇒ DebReleaseResponse
Inspect a release The Release contains release file fields, that are not relevant to the APT repo structure.
-
#read_with_http_info(deb_release_href, opts = {}) ⇒ Array<(DebReleaseResponse, Integer, Hash)>
Inspect a release The Release contains release file fields, that are not relevant to the APT repo structure.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentReleasesApi
Returns a new instance of ContentReleasesApi.
19 20 21 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(deb_release, opts = {}) ⇒ AsyncOperationResponse
Create a release Trigger an asynchronous task to create content,optionally create new repository version.
27 28 29 30 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 27 def create(deb_release, opts = {}) data, _status_code, _headers = create_with_http_info(deb_release, opts) data end |
#create_with_http_info(deb_release, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a release Trigger an asynchronous task to create content,optionally create new repository version.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 37 def create_with_http_info(deb_release, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleasesApi.create ...' end # verify the required parameter 'deb_release' is set if @api_client.config.client_side_validation && deb_release.nil? fail ArgumentError, "Missing the required parameter 'deb_release' when calling ContentReleasesApi.create" end # resource path local_var_path = '/pulp/api/v3/content/deb/releases/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(deb_release) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleasesApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleasesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebReleaseResponseList
List releases The Release contains release file fields, that are not relevant to the APT repo structure. Associated artifacts: None; contains only metadata. By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model. Note that the distribution field is part of this model, but is not added to any published release files. The "distribution" is defined as the path between ‘dists/’ and some ‘Release’ file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the "codename" or the "suite".
114 115 116 117 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 114 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebReleaseResponseList, Integer, Hash)>
List releases The Release contains release file fields, that are not relevant to the APT repo structure. Associated artifacts: None; contains only metadata. By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model. Note that the distribution field is part of this model, but is not added to any published release files. The "distribution" is defined as the path between 'dists/' and some 'Release' file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the "codename" or the "suite".
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 143 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleasesApi.list ...' end allowable_values = ["-codename", "-description", "-distribution", "-label", "-origin", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-pulp_type", "-suite", "-timestamp_of_interest", "-upstream_id", "-version", "codename", "description", "distribution", "label", "origin", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "pulp_type", "suite", "timestamp_of_interest", "upstream_id", "version"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/deb/releases/' # query parameters query_params = opts[:query_params] || {} query_params[:'codename'] = opts[:'codename'] if !opts[:'codename'].nil? query_params[:'distribution'] = opts[:'distribution'] if !opts[:'distribution'].nil? query_params[:'label'] = opts[:'label'] if !opts[:'label'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'origin'] = opts[:'origin'] if !opts[:'origin'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'package'] = opts[:'package'] if !opts[:'package'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'suite'] = opts[:'suite'] if !opts[:'suite'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginateddebReleaseResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleasesApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleasesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_release_href, opts = {}) ⇒ DebReleaseResponse
Inspect a release The Release contains release file fields, that are not relevant to the APT repo structure. Associated artifacts: None; contains only metadata. By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model. Note that the distribution field is part of this model, but is not added to any published release files. The "distribution" is defined as the path between ‘dists/’ and some ‘Release’ file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the "codename" or the "suite".
218 219 220 221 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 218 def read(deb_release_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_release_href, opts) data end |
#read_with_http_info(deb_release_href, opts = {}) ⇒ Array<(DebReleaseResponse, Integer, Hash)>
Inspect a release The Release contains release file fields, that are not relevant to the APT repo structure. Associated artifacts: None; contains only metadata. By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model. Note that the distribution field is part of this model, but is not added to any published release files. The "distribution" is defined as the path between 'dists/' and some 'Release' file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the "codename" or the "suite".
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/pulp_deb_client/api/content_releases_api.rb', line 230 def read_with_http_info(deb_release_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentReleasesApi.read ...' end # verify the required parameter 'deb_release_href' is set if @api_client.config.client_side_validation && deb_release_href.nil? fail ArgumentError, "Missing the required parameter 'deb_release_href' when calling ContentReleasesApi.read" end # resource path local_var_path = '{deb_release_href}'.sub('{' + 'deb_release_href' + '}', CGI.escape(deb_release_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DebReleaseResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentReleasesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentReleasesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |