Class: PulpDebClient::ContentSourceIndicesApi
- Inherits:
-
Object
- Object
- PulpDebClient::ContentSourceIndicesApi
- Defined in:
- lib/pulp_deb_client/api/content_source_indices_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(deb_source_index, opts = {}) ⇒ DebSourceIndexResponse
Create a source index A SourceIndex represents the source indices of a single component.
-
#create_with_http_info(deb_source_index, opts = {}) ⇒ Array<(DebSourceIndexResponse, Integer, Hash)>
Create a source index A SourceIndex represents the source indices of a single component.
-
#initialize(api_client = ApiClient.default) ⇒ ContentSourceIndicesApi
constructor
A new instance of ContentSourceIndicesApi.
-
#list(opts = {}) ⇒ PaginateddebSourceIndexResponseList
List SourceIndices A SourceIndex represents the source indices of a single component.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebSourceIndexResponseList, Integer, Hash)>
List SourceIndices A SourceIndex represents the source indices of a single component.
-
#read(deb_source_index_href, opts = {}) ⇒ DebSourceIndexResponse
Inspect a source index A SourceIndex represents the source indices of a single component.
-
#read_with_http_info(deb_source_index_href, opts = {}) ⇒ Array<(DebSourceIndexResponse, Integer, Hash)>
Inspect a source index A SourceIndex represents the source indices of a single component.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentSourceIndicesApi
19 20 21 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(deb_source_index, opts = {}) ⇒ DebSourceIndexResponse
Create a source index A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one ‘Sources’ file. May optionally include one or more of ‘Sources.gz’, ‘Sources.xz’, ‘Release’. If included, the ‘Release’ file is a legacy per-component-and-architecture Release file (with architecture always being ‘source’). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Sources’ files it needs when creating the publication. It does not make use of SourceIndex content.
27 28 29 30 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 27 def create(deb_source_index, opts = {}) data, _status_code, _headers = create_with_http_info(deb_source_index, opts) data end |
#create_with_http_info(deb_source_index, opts = {}) ⇒ Array<(DebSourceIndexResponse, Integer, Hash)>
Create a source index A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one 'Sources' file. May optionally include one or more of 'Sources.gz', 'Sources.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file (with architecture always being 'source'). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Sources' files it needs when creating the publication. It does not make use of SourceIndex content.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 37 def create_with_http_info(deb_source_index, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentSourceIndicesApi.create ...' end # verify the required parameter 'deb_source_index' is set if @api_client.config.client_side_validation && deb_source_index.nil? fail ArgumentError, "Missing the required parameter 'deb_source_index' when calling ContentSourceIndicesApi.create" end # resource path local_var_path = '/pulp/api/v3/content/deb/source_indices/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(deb_source_index) # return_type return_type = opts[:debug_return_type] || 'DebSourceIndexResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentSourceIndicesApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentSourceIndicesApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebSourceIndexResponseList
List SourceIndices A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one ‘Sources’ file. May optionally include one or more of ‘Sources.gz’, ‘Sources.xz’, ‘Release’. If included, the ‘Release’ file is a legacy per-component-and-architecture Release file (with architecture always being ‘source’). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Sources’ files it needs when creating the publication. It does not make use of SourceIndex content.
110 111 112 113 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 110 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebSourceIndexResponseList, Integer, Hash)>
List SourceIndices A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one 'Sources' file. May optionally include one or more of 'Sources.gz', 'Sources.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file (with architecture always being 'source'). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Sources' files it needs when creating the publication. It does not make use of SourceIndex content.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 135 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentSourceIndicesApi.list ...' end allowable_values = ["-component", "-pk", "-pulp_created", "-pulp_id", "-pulp_last_updated", "-pulp_type", "-relative_path", "-sha256", "-timestamp_of_interest", "-upstream_id", "component", "pk", "pulp_created", "pulp_id", "pulp_last_updated", "pulp_type", "relative_path", "sha256", "timestamp_of_interest", "upstream_id"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/deb/source_indices/' # query parameters query_params = opts[:query_params] || {} query_params[:'component'] = opts[:'component'] if !opts[:'component'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'relative_path'] = opts[:'relative_path'] if !opts[:'relative_path'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'sha256'] = opts[:'sha256'] if !opts[:'sha256'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginateddebSourceIndexResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentSourceIndicesApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentSourceIndicesApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_source_index_href, opts = {}) ⇒ DebSourceIndexResponse
Inspect a source index A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one ‘Sources’ file. May optionally include one or more of ‘Sources.gz’, ‘Sources.xz’, ‘Release’. If included, the ‘Release’ file is a legacy per-component-and-architecture Release file (with architecture always being ‘source’). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any ‘Sources’ files it needs when creating the publication. It does not make use of SourceIndex content.
206 207 208 209 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 206 def read(deb_source_index_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_source_index_href, opts) data end |
#read_with_http_info(deb_source_index_href, opts = {}) ⇒ Array<(DebSourceIndexResponse, Integer, Hash)>
Inspect a source index A SourceIndex represents the source indices of a single component. Associated artifacts: Exactly one 'Sources' file. May optionally include one or more of 'Sources.gz', 'Sources.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file (with architecture always being 'source'). Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Sources' files it needs when creating the publication. It does not make use of SourceIndex content.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pulp_deb_client/api/content_source_indices_api.rb', line 218 def read_with_http_info(deb_source_index_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentSourceIndicesApi.read ...' end # verify the required parameter 'deb_source_index_href' is set if @api_client.config.client_side_validation && deb_source_index_href.nil? fail ArgumentError, "Missing the required parameter 'deb_source_index_href' when calling ContentSourceIndicesApi.read" end # resource path local_var_path = '{deb_source_index_href}'.sub('{' + 'deb_source_index_href' + '}', CGI.escape(deb_source_index_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DebSourceIndexResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentSourceIndicesApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentSourceIndicesApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |