Class: PulpDebClient::DebAptPublicationResponse
- Inherits:
-
Object
- Object
- PulpDebClient::DebAptPublicationResponse
- Defined in:
- lib/pulp_deb_client/models/deb_apt_publication_response.rb
Overview
A Serializer for AptPublication.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#checkpoint ⇒ Object
Returns the value of attribute checkpoint.
-
#excluded_package_metadata_fields ⇒ Object
Package metadata field names to omit from generated Packages indices.
-
#layout ⇒ Object
How to layout the packages within the published repository.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#publish_legacy_release_files ⇒ Object
Whether or not to publish Legacy per-component-and-architecture Release files.
-
#publish_upstream_release_fields ⇒ Object
Returns the value of attribute publish_upstream_release_fields.
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#repository ⇒ Object
A URI of the repository to be published.
-
#repository_version ⇒ Object
Returns the value of attribute repository_version.
-
#signing_service ⇒ Object
Sign Release files with this signing key.
-
#simple ⇒ Object
Activate simple publishing mode (all packages in one release component).
-
#structured ⇒ Object
Activate structured publishing mode.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DebAptPublicationResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DebAptPublicationResponse
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebAptPublicationResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebAptPublicationResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'repository_version') self.repository_version = attributes[:'repository_version'] end if attributes.key?(:'repository') self.repository = attributes[:'repository'] end if attributes.key?(:'simple') self.simple = attributes[:'simple'] else self.simple = false end if attributes.key?(:'structured') self.structured = attributes[:'structured'] else self.structured = true end if attributes.key?(:'checkpoint') self.checkpoint = attributes[:'checkpoint'] end if attributes.key?(:'signing_service') self.signing_service = attributes[:'signing_service'] end if attributes.key?(:'publish_upstream_release_fields') self.publish_upstream_release_fields = attributes[:'publish_upstream_release_fields'] end if attributes.key?(:'publish_legacy_release_files') self.publish_legacy_release_files = attributes[:'publish_legacy_release_files'] else self.publish_legacy_release_files = false end if attributes.key?(:'excluded_package_metadata_fields') if (value = attributes[:'excluded_package_metadata_fields']).is_a?(Array) self. = value end end if attributes.key?(:'layout') self.layout = attributes[:'layout'] end end |
Instance Attribute Details
#checkpoint ⇒ Object
Returns the value of attribute checkpoint.
41 42 43 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 41 def checkpoint @checkpoint end |
#excluded_package_metadata_fields ⇒ Object
Package metadata field names to omit from generated Packages indices. This only affects custom package metadata fields during structured publication. Core package metadata fields are never filtered. Matching is case-insensitive. Example: ['Phased-Update-Percentage'].
52 53 54 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 52 def @excluded_package_metadata_fields end |
#layout ⇒ Object
How to layout the packages within the published repository. * nested_alphabetically - nested_alphabetically * nested_by_digest - nested_by_digest * nested_by_both - nested_by_both
55 56 57 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 55 def layout @layout end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 22 def prn @prn end |
#publish_legacy_release_files ⇒ Object
Whether or not to publish Legacy per-component-and-architecture Release files.
49 50 51 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 49 def publish_legacy_release_files @publish_legacy_release_files end |
#publish_upstream_release_fields ⇒ Object
Returns the value of attribute publish_upstream_release_fields.
46 47 48 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 46 def publish_upstream_release_fields @publish_upstream_release_fields end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
28 29 30 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#repository ⇒ Object
A URI of the repository to be published.
33 34 35 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 33 def repository @repository end |
#repository_version ⇒ Object
Returns the value of attribute repository_version.
30 31 32 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 30 def repository_version @repository_version end |
#signing_service ⇒ Object
Sign Release files with this signing key
44 45 46 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 44 def signing_service @signing_service end |
#simple ⇒ Object
Activate simple publishing mode (all packages in one release component).
36 37 38 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 36 def simple @simple end |
#structured ⇒ Object
Activate structured publishing mode.
39 40 41 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 39 def structured @structured end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 285 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpDebClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
100 101 102 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 100 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 80 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'repository_version' => :'repository_version', :'repository' => :'repository', :'simple' => :'simple', :'structured' => :'structured', :'checkpoint' => :'checkpoint', :'signing_service' => :'signing_service', :'publish_upstream_release_fields' => :'publish_upstream_release_fields', :'publish_legacy_release_files' => :'publish_legacy_release_files', :'excluded_package_metadata_fields' => :'excluded_package_metadata_fields', :'layout' => :'layout' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 125 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 105 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'repository_version' => :'String', :'repository' => :'String', :'simple' => :'Boolean', :'structured' => :'Boolean', :'checkpoint' => :'Boolean', :'signing_service' => :'String', :'publish_upstream_release_fields' => :'Boolean', :'publish_legacy_release_files' => :'Boolean', :'excluded_package_metadata_fields' => :'Array<String>', :'layout' => :'LayoutEnum' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && repository_version == o.repository_version && repository == o.repository && simple == o.simple && structured == o.structured && checkpoint == o.checkpoint && signing_service == o.signing_service && publish_upstream_release_fields == o.publish_upstream_release_fields && publish_legacy_release_files == o.publish_legacy_release_files && == o. && layout == o.layout end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 356 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 254 def hash [pulp_href, prn, pulp_created, pulp_last_updated, repository_version, repository, simple, structured, checkpoint, signing_service, publish_upstream_release_fields, publish_legacy_release_files, , layout].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
212 213 214 215 216 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 212 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
332 333 334 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 332 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 338 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
326 327 328 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 326 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
220 221 222 223 |
# File 'lib/pulp_deb_client/models/deb_apt_publication_response.rb', line 220 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |