Class: PulpDebClient::DebInstallerFileIndex
- Inherits:
-
Object
- Object
- PulpDebClient::DebInstallerFileIndex
- Defined in:
- lib/pulp_deb_client/models/deb_installer_file_index.rb
Overview
A serializer for InstallerFileIndex.
Instance Attribute Summary collapse
-
#architecture ⇒ Object
Architecture of the component - architecture combination.
-
#artifacts ⇒ Object
A dict mapping relative paths inside the Content to the correspondingArtifact URLs.
-
#component ⇒ Object
Component of the component - architecture combination.
-
#overwrite ⇒ Object
When set to true, existing content in the repository with the same unique key will be silently overwritten.
-
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
-
#relative_path ⇒ Object
Path of directory containing MD5SUMS and SHA256SUMS relative to url.
-
#repository ⇒ Object
A URI of a repository the new content unit should be associated with.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DebInstallerFileIndex
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DebInstallerFileIndex
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebInstallerFileIndex` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebInstallerFileIndex`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'repository') self.repository = attributes[:'repository'] end if attributes.key?(:'overwrite') self.overwrite = attributes[:'overwrite'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'artifacts') self.artifacts = attributes[:'artifacts'] else self.artifacts = nil end if attributes.key?(:'component') self.component = attributes[:'component'] else self.component = nil end if attributes.key?(:'architecture') self.architecture = attributes[:'architecture'] else self.architecture = nil end if attributes.key?(:'relative_path') self.relative_path = attributes[:'relative_path'] end end |
Instance Attribute Details
#architecture ⇒ Object
Architecture of the component - architecture combination.
35 36 37 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 35 def architecture @architecture end |
#artifacts ⇒ Object
A dict mapping relative paths inside the Content to the correspondingArtifact URLs. E.g.: {‘relative/path’: ‘/artifacts/1/’
29 30 31 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 29 def artifacts @artifacts end |
#component ⇒ Object
Component of the component - architecture combination.
32 33 34 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 32 def component @component end |
#overwrite ⇒ Object
When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when ‘repository’ is specified. Defaults to true.
23 24 25 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 23 def overwrite @overwrite end |
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
26 27 28 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 26 def pulp_labels @pulp_labels end |
#relative_path ⇒ Object
Path of directory containing MD5SUMS and SHA256SUMS relative to url.
38 39 40 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 38 def relative_path @relative_path end |
#repository ⇒ Object
A URI of a repository the new content unit should be associated with.
20 21 22 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 20 def repository @repository end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 269 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpDebClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 54 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 41 def self.attribute_map { :'repository' => :'repository', :'overwrite' => :'overwrite', :'pulp_labels' => :'pulp_labels', :'artifacts' => :'artifacts', :'component' => :'component', :'architecture' => :'architecture', :'relative_path' => :'relative_path' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 59 def self.openapi_types { :'repository' => :'String', :'overwrite' => :'Boolean', :'pulp_labels' => :'Hash<String, String>', :'artifacts' => :'Object', :'component' => :'String', :'architecture' => :'String', :'relative_path' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && repository == o.repository && overwrite == o.overwrite && pulp_labels == o.pulp_labels && artifacts == o.artifacts && component == o.component && architecture == o.architecture && relative_path == o.relative_path end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 340 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 238 def hash [repository, overwrite, pulp_labels, artifacts, component, architecture, relative_path].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @artifacts.nil? invalid_properties.push('invalid value for "artifacts", artifacts cannot be nil.') end if @component.nil? invalid_properties.push('invalid value for "component", component cannot be nil.') end if @component.to_s.length < 1 invalid_properties.push('invalid value for "component", the character length must be great than or equal to 1.') end if @architecture.nil? invalid_properties.push('invalid value for "architecture", architecture cannot be nil.') end if @architecture.to_s.length < 1 invalid_properties.push('invalid value for "architecture", the character length must be great than or equal to 1.') end if !@relative_path.nil? && @relative_path.to_s.length < 1 invalid_properties.push('invalid value for "relative_path", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
316 317 318 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 316 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
310 311 312 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 310 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 170 171 172 |
# File 'lib/pulp_deb_client/models/deb_installer_file_index.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @artifacts.nil? return false if @component.nil? return false if @component.to_s.length < 1 return false if @architecture.nil? return false if @architecture.to_s.length < 1 return false if !@relative_path.nil? && @relative_path.to_s.length < 1 true end |