Class: PulpDebClient::DebPackageResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_deb_client/models/deb_package_response.rb

Overview

A Serializer for Package.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DebPackageResponse

Initializes the object



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 229

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebPackageResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebPackageResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pulp_href')
    self.pulp_href = attributes[:'pulp_href']
  end

  if attributes.key?(:'prn')
    self.prn = attributes[:'prn']
  end

  if attributes.key?(:'pulp_created')
    self.pulp_created = attributes[:'pulp_created']
  end

  if attributes.key?(:'pulp_last_updated')
    self.pulp_last_updated = attributes[:'pulp_last_updated']
  end

  if attributes.key?(:'artifact')
    self.artifact = attributes[:'artifact']
  end

  if attributes.key?(:'relative_path')
    self.relative_path = attributes[:'relative_path']
  end

  if attributes.key?(:'distribution')
    self.distribution = attributes[:'distribution']
  end

  if attributes.key?(:'component')
    self.component = attributes[:'component']
  end

  if attributes.key?(:'md5')
    self.md5 = attributes[:'md5']
  end

  if attributes.key?(:'sha1')
    self.sha1 = attributes[:'sha1']
  end

  if attributes.key?(:'sha224')
    self.sha224 = attributes[:'sha224']
  end

  if attributes.key?(:'sha256')
    self.sha256 = attributes[:'sha256']
  end

  if attributes.key?(:'sha384')
    self.sha384 = attributes[:'sha384']
  end

  if attributes.key?(:'sha512')
    self.sha512 = attributes[:'sha512']
  end

  if attributes.key?(:'package')
    self.package = attributes[:'package']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'architecture')
    self.architecture = attributes[:'architecture']
  end

  if attributes.key?(:'section')
    self.section = attributes[:'section']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'tag')
    self.tag = attributes[:'tag']
  end

  if attributes.key?(:'bugs')
    self.bugs = attributes[:'bugs']
  end

  if attributes.key?(:'essential')
    self.essential = attributes[:'essential']
  end

  if attributes.key?(:'build_essential')
    self.build_essential = attributes[:'build_essential']
  end

  if attributes.key?(:'installed_size')
    self.installed_size = attributes[:'installed_size']
  end

  if attributes.key?(:'maintainer')
    self.maintainer = attributes[:'maintainer']
  end

  if attributes.key?(:'original_maintainer')
    self.original_maintainer = attributes[:'original_maintainer']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'description_md5')
    self.description_md5 = attributes[:'description_md5']
  end

  if attributes.key?(:'homepage')
    self.homepage = attributes[:'homepage']
  end

  if attributes.key?(:'built_using')
    self.built_using = attributes[:'built_using']
  end

  if attributes.key?(:'auto_built_package')
    self.auto_built_package = attributes[:'auto_built_package']
  end

  if attributes.key?(:'multi_arch')
    self.multi_arch = attributes[:'multi_arch']
  end

  if attributes.key?(:'breaks')
    self.breaks = attributes[:'breaks']
  end

  if attributes.key?(:'conflicts')
    self.conflicts = attributes[:'conflicts']
  end

  if attributes.key?(:'depends')
    self.depends = attributes[:'depends']
  end

  if attributes.key?(:'recommends')
    self.recommends = attributes[:'recommends']
  end

  if attributes.key?(:'suggests')
    self.suggests = attributes[:'suggests']
  end

  if attributes.key?(:'enhances')
    self.enhances = attributes[:'enhances']
  end

  if attributes.key?(:'pre_depends')
    self.pre_depends = attributes[:'pre_depends']
  end

  if attributes.key?(:'provides')
    self.provides = attributes[:'provides']
  end

  if attributes.key?(:'replaces')
    self.replaces = attributes[:'replaces']
  end
end

Instance Attribute Details

#architectureObject

Returns the value of attribute architecture.



66
67
68
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 66

def architecture
  @architecture
end

#artifactObject

Artifact file representing the physical content



31
32
33
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 31

def artifact
  @artifact
end

#auto_built_packageObject

Returns the value of attribute auto_built_package.



96
97
98
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 96

def auto_built_package
  @auto_built_package
end

#breaksObject

Returns the value of attribute breaks.



100
101
102
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 100

def breaks
  @breaks
end

#bugsObject

Returns the value of attribute bugs.



76
77
78
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 76

def bugs
  @bugs
end

#build_essentialObject

Returns the value of attribute build_essential.



80
81
82
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 80

def build_essential
  @build_essential
end

#built_usingObject

Returns the value of attribute built_using.



94
95
96
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 94

def built_using
  @built_using
end

#componentObject

Name of the component.



40
41
42
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 40

def component
  @component
end

#conflictsObject

Returns the value of attribute conflicts.



102
103
104
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 102

def conflicts
  @conflicts
end

#dependsObject

Returns the value of attribute depends.



104
105
106
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 104

def depends
  @depends
end

#descriptionObject

Returns the value of attribute description.



88
89
90
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 88

def description
  @description
end

#description_md5Object

Returns the value of attribute description_md5.



90
91
92
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 90

def description_md5
  @description_md5
end

#distributionObject

Name of the distribution.



37
38
39
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 37

def distribution
  @distribution
end

#enhancesObject

Returns the value of attribute enhances.



110
111
112
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 110

def enhances
  @enhances
end

#essentialObject

Returns the value of attribute essential.



78
79
80
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 78

def essential
  @essential
end

#homepageObject

Returns the value of attribute homepage.



92
93
94
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 92

def homepage
  @homepage
end

#installed_sizeObject

Returns the value of attribute installed_size.



82
83
84
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 82

def installed_size
  @installed_size
end

#maintainerObject

Returns the value of attribute maintainer.



84
85
86
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 84

def maintainer
  @maintainer
end

#md5Object

The MD5 checksum if available.



43
44
45
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 43

def md5
  @md5
end

#multi_archObject

Returns the value of attribute multi_arch.



98
99
100
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 98

def multi_arch
  @multi_arch
end

#originObject

Returns the value of attribute origin.



72
73
74
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 72

def origin
  @origin
end

#original_maintainerObject

Returns the value of attribute original_maintainer.



86
87
88
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 86

def original_maintainer
  @original_maintainer
end

#packageObject

Returns the value of attribute package.



60
61
62
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 60

def package
  @package
end

#pre_dependsObject

Returns the value of attribute pre_depends.



112
113
114
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 112

def pre_depends
  @pre_depends
end

#priorityObject

Returns the value of attribute priority.



70
71
72
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 70

def priority
  @priority
end

#prnObject

The Pulp Resource Name (PRN).



22
23
24
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 22

def prn
  @prn
end

#providesObject

Returns the value of attribute provides.



114
115
116
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 114

def provides
  @provides
end

#pulp_createdObject

Timestamp of creation.



25
26
27
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 25

def pulp_created
  @pulp_created
end

#pulp_hrefObject

Returns the value of attribute pulp_href.



19
20
21
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 19

def pulp_href
  @pulp_href
end

#pulp_last_updatedObject

Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.



28
29
30
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 28

def pulp_last_updated
  @pulp_last_updated
end

#recommendsObject

Returns the value of attribute recommends.



106
107
108
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 106

def recommends
  @recommends
end

#relative_pathObject

Path where the artifact is located relative to distributions base_path



34
35
36
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 34

def relative_path
  @relative_path
end

#replacesObject

Returns the value of attribute replaces.



116
117
118
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 116

def replaces
  @replaces
end

#sectionObject

Returns the value of attribute section.



68
69
70
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 68

def section
  @section
end

#sha1Object

The SHA-1 checksum if available.



46
47
48
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 46

def sha1
  @sha1
end

#sha224Object

The SHA-224 checksum if available.



49
50
51
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 49

def sha224
  @sha224
end

#sha256Object

The SHA-256 checksum if available.



52
53
54
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 52

def sha256
  @sha256
end

#sha384Object

The SHA-384 checksum if available.



55
56
57
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 55

def sha384
  @sha384
end

#sha512Object

The SHA-512 checksum if available.



58
59
60
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 58

def sha512
  @sha512
end

#sourceObject

Returns the value of attribute source.



62
63
64
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 62

def source
  @source
end

#suggestsObject

Returns the value of attribute suggests.



108
109
110
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 108

def suggests
  @suggests
end

#tagObject

Returns the value of attribute tag.



74
75
76
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 74

def tag
  @tag
end

#versionObject

Returns the value of attribute version.



64
65
66
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 64

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 519

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpDebClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



168
169
170
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 168

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 119

def self.attribute_map
  {
    :'pulp_href' => :'pulp_href',
    :'prn' => :'prn',
    :'pulp_created' => :'pulp_created',
    :'pulp_last_updated' => :'pulp_last_updated',
    :'artifact' => :'artifact',
    :'relative_path' => :'relative_path',
    :'distribution' => :'distribution',
    :'component' => :'component',
    :'md5' => :'md5',
    :'sha1' => :'sha1',
    :'sha224' => :'sha224',
    :'sha256' => :'sha256',
    :'sha384' => :'sha384',
    :'sha512' => :'sha512',
    :'package' => :'package',
    :'source' => :'source',
    :'version' => :'version',
    :'architecture' => :'architecture',
    :'section' => :'section',
    :'priority' => :'priority',
    :'origin' => :'origin',
    :'tag' => :'tag',
    :'bugs' => :'bugs',
    :'essential' => :'essential',
    :'build_essential' => :'build_essential',
    :'installed_size' => :'installed_size',
    :'maintainer' => :'maintainer',
    :'original_maintainer' => :'original_maintainer',
    :'description' => :'description',
    :'description_md5' => :'description_md5',
    :'homepage' => :'homepage',
    :'built_using' => :'built_using',
    :'auto_built_package' => :'auto_built_package',
    :'multi_arch' => :'multi_arch',
    :'breaks' => :'breaks',
    :'conflicts' => :'conflicts',
    :'depends' => :'depends',
    :'recommends' => :'recommends',
    :'suggests' => :'suggests',
    :'enhances' => :'enhances',
    :'pre_depends' => :'pre_depends',
    :'provides' => :'provides',
    :'replaces' => :'replaces'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 495

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



222
223
224
225
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 222

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 173

def self.openapi_types
  {
    :'pulp_href' => :'String',
    :'prn' => :'String',
    :'pulp_created' => :'Time',
    :'pulp_last_updated' => :'Time',
    :'artifact' => :'String',
    :'relative_path' => :'String',
    :'distribution' => :'String',
    :'component' => :'String',
    :'md5' => :'String',
    :'sha1' => :'String',
    :'sha224' => :'String',
    :'sha256' => :'String',
    :'sha384' => :'String',
    :'sha512' => :'String',
    :'package' => :'String',
    :'source' => :'String',
    :'version' => :'String',
    :'architecture' => :'String',
    :'section' => :'String',
    :'priority' => :'String',
    :'origin' => :'String',
    :'tag' => :'String',
    :'bugs' => :'String',
    :'essential' => :'String',
    :'build_essential' => :'String',
    :'installed_size' => :'String',
    :'maintainer' => :'String',
    :'original_maintainer' => :'String',
    :'description' => :'String',
    :'description_md5' => :'String',
    :'homepage' => :'String',
    :'built_using' => :'String',
    :'auto_built_package' => :'String',
    :'multi_arch' => :'String',
    :'breaks' => :'String',
    :'conflicts' => :'String',
    :'depends' => :'String',
    :'recommends' => :'String',
    :'suggests' => :'String',
    :'enhances' => :'String',
    :'pre_depends' => :'String',
    :'provides' => :'String',
    :'replaces' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 432

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pulp_href == o.pulp_href &&
      prn == o.prn &&
      pulp_created == o.pulp_created &&
      pulp_last_updated == o.pulp_last_updated &&
      artifact == o.artifact &&
      relative_path == o.relative_path &&
      distribution == o.distribution &&
      component == o.component &&
      md5 == o.md5 &&
      sha1 == o.sha1 &&
      sha224 == o.sha224 &&
      sha256 == o.sha256 &&
      sha384 == o.sha384 &&
      sha512 == o.sha512 &&
      package == o.package &&
      source == o.source &&
      version == o.version &&
      architecture == o.architecture &&
      section == o.section &&
      priority == o.priority &&
      origin == o.origin &&
      tag == o.tag &&
      bugs == o.bugs &&
      essential == o.essential &&
      build_essential == o.build_essential &&
      installed_size == o.installed_size &&
      maintainer == o.maintainer &&
      original_maintainer == o.original_maintainer &&
      description == o.description &&
      description_md5 == o.description_md5 &&
      homepage == o.homepage &&
      built_using == o.built_using &&
      auto_built_package == o.auto_built_package &&
      multi_arch == o.multi_arch &&
      breaks == o.breaks &&
      conflicts == o.conflicts &&
      depends == o.depends &&
      recommends == o.recommends &&
      suggests == o.suggests &&
      enhances == o.enhances &&
      pre_depends == o.pre_depends &&
      provides == o.provides &&
      replaces == o.replaces
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 590

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


482
483
484
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 482

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



488
489
490
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 488

def hash
  [pulp_href, prn, pulp_created, pulp_last_updated, artifact, relative_path, distribution, component, md5, sha1, sha224, sha256, sha384, sha512, package, source, version, architecture, section, priority, origin, tag, bugs, essential, build_essential, installed_size, maintainer, original_maintainer, description, description_md5, homepage, built_using, auto_built_package, multi_arch, breaks, conflicts, depends, recommends, suggests, enhances, pre_depends, provides, replaces].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



417
418
419
420
421
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 417

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



566
567
568
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 566

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 572

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



560
561
562
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 560

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



425
426
427
428
# File 'lib/pulp_deb_client/models/deb_package_response.rb', line 425

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end