Class: PulpDebClient::DebReleaseFile
- Inherits:
-
Object
- Object
- PulpDebClient::DebReleaseFile
- Defined in:
- lib/pulp_deb_client/models/deb_release_file.rb
Overview
A serializer for ReleaseFile.
Instance Attribute Summary collapse
-
#artifacts ⇒ Object
A dict mapping relative paths inside the Content to the correspondingArtifact URLs.
-
#codename ⇒ Object
Codename of the release, e.g.
-
#distribution ⇒ Object
Distribution of the release, e.g.
-
#overwrite ⇒ Object
When set to true, existing content in the repository with the same unique key will be silently overwritten.
-
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
-
#relative_path ⇒ Object
Path of file relative to url.
-
#repository ⇒ Object
A URI of a repository the new content unit should be associated with.
-
#suite ⇒ Object
Suite of the release, e.g.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DebReleaseFile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DebReleaseFile
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebReleaseFile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebReleaseFile`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'repository') self.repository = attributes[:'repository'] end if attributes.key?(:'overwrite') self.overwrite = attributes[:'overwrite'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'artifacts') self.artifacts = attributes[:'artifacts'] else self.artifacts = nil end if attributes.key?(:'codename') self.codename = attributes[:'codename'] end if attributes.key?(:'suite') self.suite = attributes[:'suite'] end if attributes.key?(:'distribution') self.distribution = attributes[:'distribution'] else self.distribution = nil end if attributes.key?(:'relative_path') self.relative_path = attributes[:'relative_path'] end end |
Instance Attribute Details
#artifacts ⇒ Object
A dict mapping relative paths inside the Content to the correspondingArtifact URLs. E.g.: {‘relative/path’: ‘/artifacts/1/’
29 30 31 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 29 def artifacts @artifacts end |
#codename ⇒ Object
Codename of the release, e.g. "buster".
32 33 34 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 32 def codename @codename end |
#distribution ⇒ Object
Distribution of the release, e.g. "stable/updates".
38 39 40 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 38 def distribution @distribution end |
#overwrite ⇒ Object
When set to true, existing content in the repository with the same unique key will be silently overwritten. When set to false, the task will fail if content would be overwritten. Only used when ‘repository’ is specified. Defaults to true.
23 24 25 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 23 def overwrite @overwrite end |
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
26 27 28 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 26 def pulp_labels @pulp_labels end |
#relative_path ⇒ Object
Path of file relative to url.
41 42 43 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 41 def relative_path @relative_path end |
#repository ⇒ Object
A URI of a repository the new content unit should be associated with.
20 21 22 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 20 def repository @repository end |
#suite ⇒ Object
Suite of the release, e.g. "stable".
35 36 37 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 35 def suite @suite end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 291 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpDebClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 58 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 44 def self.attribute_map { :'repository' => :'repository', :'overwrite' => :'overwrite', :'pulp_labels' => :'pulp_labels', :'artifacts' => :'artifacts', :'codename' => :'codename', :'suite' => :'suite', :'distribution' => :'distribution', :'relative_path' => :'relative_path' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 63 def self.openapi_types { :'repository' => :'String', :'overwrite' => :'Boolean', :'pulp_labels' => :'Hash<String, String>', :'artifacts' => :'Object', :'codename' => :'String', :'suite' => :'String', :'distribution' => :'String', :'relative_path' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && repository == o.repository && overwrite == o.overwrite && pulp_labels == o.pulp_labels && artifacts == o.artifacts && codename == o.codename && suite == o.suite && distribution == o.distribution && relative_path == o.relative_path end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 260 def hash [repository, overwrite, pulp_labels, artifacts, codename, suite, distribution, relative_path].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @artifacts.nil? invalid_properties.push('invalid value for "artifacts", artifacts cannot be nil.') end if !@codename.nil? && @codename.to_s.length < 1 invalid_properties.push('invalid value for "codename", the character length must be great than or equal to 1.') end if !@suite.nil? && @suite.to_s.length < 1 invalid_properties.push('invalid value for "suite", the character length must be great than or equal to 1.') end if @distribution.nil? invalid_properties.push('invalid value for "distribution", distribution cannot be nil.') end if @distribution.to_s.length < 1 invalid_properties.push('invalid value for "distribution", the character length must be great than or equal to 1.') end if !@relative_path.nil? && @relative_path.to_s.length < 1 invalid_properties.push('invalid value for "relative_path", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/pulp_deb_client/models/deb_release_file.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @artifacts.nil? return false if !@codename.nil? && @codename.to_s.length < 1 return false if !@suite.nil? && @suite.to_s.length < 1 return false if @distribution.nil? return false if @distribution.to_s.length < 1 return false if !@relative_path.nil? && @relative_path.to_s.length < 1 true end |