Class: PulpDebClient::PatcheddebAptRepository
- Inherits:
-
Object
- Object
- PulpDebClient::PatcheddebAptRepository
- Defined in:
- lib/pulp_deb_client/models/patcheddeb_apt_repository.rb
Overview
A Serializer for AptRepository.
Instance Attribute Summary collapse
-
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
-
#description ⇒ Object
An optional description.
-
#name ⇒ Object
A unique name for this repository.
-
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service.
-
#package_signing_fingerprint_release_overrides ⇒ Object
A dictionary of Release distributions and the Package Signing Fingerprints they should use.
-
#package_signing_service ⇒ Object
A reference to an associated package signing service.
-
#publish_upstream_release_fields ⇒ Object
Previously, pulp_deb only synced the Release file fields codename and suite, now version, origin, label, and description are also synced.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#remote ⇒ Object
An optional remote to use by default when syncing.
-
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository.
-
#retain_repo_versions ⇒ Object
Retain X versions of the repository.
-
#signing_service ⇒ Object
A reference to an associated signing service.
-
#signing_service_release_overrides ⇒ Object
A dictionary of Release distributions and the Signing Service URLs they should use.Example: \"/pulp/api/v3/signing-services/433a1f70-c589-4413-a803-c50b842ea9b5/\".
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatcheddebAptRepository
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PatcheddebAptRepository
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::PatcheddebAptRepository` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::PatcheddebAptRepository`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'retain_repo_versions') self.retain_repo_versions = attributes[:'retain_repo_versions'] end if attributes.key?(:'retain_checkpoints') self.retain_checkpoints = attributes[:'retain_checkpoints'] end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'autopublish') self.autopublish = attributes[:'autopublish'] else self.autopublish = false end if attributes.key?(:'publish_upstream_release_fields') self.publish_upstream_release_fields = attributes[:'publish_upstream_release_fields'] end if attributes.key?(:'signing_service') self.signing_service = attributes[:'signing_service'] end if attributes.key?(:'signing_service_release_overrides') if (value = attributes[:'signing_service_release_overrides']).is_a?(Hash) self.signing_service_release_overrides = value end end if attributes.key?(:'package_signing_fingerprint_release_overrides') if (value = attributes[:'package_signing_fingerprint_release_overrides']).is_a?(Hash) self.package_signing_fingerprint_release_overrides = value end end if attributes.key?(:'package_signing_service') self.package_signing_service = attributes[:'package_signing_service'] end if attributes.key?(:'package_signing_fingerprint') self.package_signing_fingerprint = attributes[:'package_signing_fingerprint'] end end |
Instance Attribute Details
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository. Will create a standard structured APT publication.
37 38 39 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 37 def autopublish @autopublish end |
#description ⇒ Object
An optional description.
25 26 27 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 25 def description @description end |
#name ⇒ Object
A unique name for this repository.
22 23 24 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 22 def name @name end |
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service. Format: 'v
55 56 57 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 55 def package_signing_fingerprint @package_signing_fingerprint end |
#package_signing_fingerprint_release_overrides ⇒ Object
A dictionary of Release distributions and the Package Signing Fingerprints they should use. Example: \"v4:7FC42CD5F3D8EEC37FC42CD5F3D8EEC3DEADBEEF\"
49 50 51 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 49 def package_signing_fingerprint_release_overrides @package_signing_fingerprint_release_overrides end |
#package_signing_service ⇒ Object
A reference to an associated package signing service.
52 53 54 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 52 def package_signing_service @package_signing_service end |
#publish_upstream_release_fields ⇒ Object
Previously, pulp_deb only synced the Release file fields codename and suite, now version, origin, label, and description are also synced. Setting this setting to False will make Pulp revert to the old behaviour of using it's own internal values for the new fields during publish. This is primarily intended to avoid a sudden change in behaviour for existing Pulp repositories, since many Release file field changes need to be accepted by hosts consuming the published repository. The default for new repositories is True.
40 41 42 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 40 def publish_upstream_release_fields @publish_upstream_release_fields end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
19 20 21 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 19 def pulp_labels @pulp_labels end |
#remote ⇒ Object
An optional remote to use by default when syncing.
34 35 36 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 34 def remote @remote end |
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.
31 32 33 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 31 def retain_checkpoints @retain_checkpoints end |
#retain_repo_versions ⇒ Object
Retain X versions of the repository. Default is null which retains all versions.
28 29 30 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 28 def retain_repo_versions @retain_repo_versions end |
#signing_service ⇒ Object
A reference to an associated signing service. Used if AptPublication.signing_service is not set
43 44 45 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 43 def signing_service @signing_service end |
#signing_service_release_overrides ⇒ Object
A dictionary of Release distributions and the Signing Service URLs they should use.Example: \"/pulp/api/v3/signing-services/433a1f70-c589-4413-a803-c50b842ea9b5/\"
46 47 48 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 46 def signing_service_release_overrides @signing_service_release_overrides end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 351 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpDebClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 77 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 58 def self.attribute_map { :'pulp_labels' => :'pulp_labels', :'name' => :'name', :'description' => :'description', :'retain_repo_versions' => :'retain_repo_versions', :'retain_checkpoints' => :'retain_checkpoints', :'remote' => :'remote', :'autopublish' => :'autopublish', :'publish_upstream_release_fields' => :'publish_upstream_release_fields', :'signing_service' => :'signing_service', :'signing_service_release_overrides' => :'signing_service_release_overrides', :'package_signing_fingerprint_release_overrides' => :'package_signing_fingerprint_release_overrides', :'package_signing_service' => :'package_signing_service', :'package_signing_fingerprint' => :'package_signing_fingerprint' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 327 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 101 def self.openapi_nullable Set.new([ :'description', :'retain_repo_versions', :'retain_checkpoints', :'remote', :'signing_service', :'package_signing_service', :'package_signing_fingerprint' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 82 def self.openapi_types { :'pulp_labels' => :'Hash<String, String>', :'name' => :'String', :'description' => :'String', :'retain_repo_versions' => :'Integer', :'retain_checkpoints' => :'Integer', :'remote' => :'String', :'autopublish' => :'Boolean', :'publish_upstream_release_fields' => :'Boolean', :'signing_service' => :'String', :'signing_service_release_overrides' => :'Hash<String, String>', :'package_signing_fingerprint_release_overrides' => :'Hash<String, String>', :'package_signing_service' => :'String', :'package_signing_fingerprint' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 294 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_labels == o.pulp_labels && name == o.name && description == o.description && retain_repo_versions == o.retain_repo_versions && retain_checkpoints == o.retain_checkpoints && remote == o.remote && autopublish == o.autopublish && publish_upstream_release_fields == o.publish_upstream_release_fields && signing_service == o.signing_service && signing_service_release_overrides == o.signing_service_release_overrides && package_signing_fingerprint_release_overrides == o.package_signing_fingerprint_release_overrides && package_signing_service == o.package_signing_service && package_signing_fingerprint == o.package_signing_fingerprint end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
314 315 316 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 314 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 320 def hash [pulp_labels, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, publish_upstream_release_fields, signing_service, signing_service_release_overrides, package_signing_fingerprint_release_overrides, package_signing_service, package_signing_fingerprint].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 191 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end if !@retain_checkpoints.nil? && @retain_checkpoints < 1 invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.') end if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be smaller than or equal to 68.') end if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1 invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
398 399 400 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 398 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
392 393 394 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 392 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/pulp_deb_client/models/patcheddeb_apt_repository.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length < 1 return false if !@description.nil? && @description.to_s.length < 1 return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1 return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1 return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length < 1 true end |