Class: PulpDebClient::RepositoriesAptApi
- Inherits:
-
Object
- Object
- PulpDebClient::RepositoriesAptApi
- Defined in:
- lib/pulp_deb_client/api/repositories_apt_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(deb_apt_repository, opts = {}) ⇒ DebAptRepositoryResponse
Create an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#create_with_http_info(deb_apt_repository, opts = {}) ⇒ Array<(DebAptRepositoryResponse, Integer, Hash)>
Create an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#delete(deb_apt_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete an apt repository Trigger an asynchronous delete task.
-
#delete_with_http_info(deb_apt_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an apt repository Trigger an asynchronous delete task.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesAptApi
constructor
A new instance of RepositoriesAptApi.
-
#list(opts = {}) ⇒ PaginateddebAptRepositoryResponseList
List apt repositorys An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebAptRepositoryResponseList, Integer, Hash)>
List apt repositorys An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#modify(deb_apt_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#modify_with_http_info(deb_apt_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#partial_update(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) ⇒ AsyncOperationResponse
Update an apt repository Trigger an asynchronous partial update task.
-
#partial_update_with_http_info(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update an apt repository Trigger an asynchronous partial update task.
-
#read(deb_apt_repository_href, opts = {}) ⇒ DebAptRepositoryResponse
Inspect an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#read_with_http_info(deb_apt_repository_href, opts = {}) ⇒ Array<(DebAptRepositoryResponse, Integer, Hash)>
Inspect an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository.
-
#sync(deb_apt_repository_href, apt_repository_sync_url, opts = {}) ⇒ AsyncOperationResponse
Sync from remote Trigger an asynchronous task to sync content.
-
#sync_with_http_info(deb_apt_repository_href, apt_repository_sync_url, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from remote Trigger an asynchronous task to sync content.
-
#update(deb_apt_repository_href, deb_apt_repository, opts = {}) ⇒ AsyncOperationResponse
Update an apt repository Trigger an asynchronous update task.
-
#update_with_http_info(deb_apt_repository_href, deb_apt_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update an apt repository Trigger an asynchronous update task.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesAptApi
Returns a new instance of RepositoriesAptApi.
19 20 21 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(deb_apt_repository, opts = {}) ⇒ DebAptRepositoryResponse
Create an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
27 28 29 30 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 27 def create(deb_apt_repository, opts = {}) data, _status_code, _headers = create_with_http_info(deb_apt_repository, opts) data end |
#create_with_http_info(deb_apt_repository, opts = {}) ⇒ Array<(DebAptRepositoryResponse, Integer, Hash)>
Create an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 37 def create_with_http_info(deb_apt_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.create ...' end # verify the required parameter 'deb_apt_repository' is set if @api_client.config.client_side_validation && deb_apt_repository.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository' when calling RepositoriesAptApi.create" end # resource path local_var_path = '/pulp/api/v3/repositories/deb/apt/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(deb_apt_repository) # return_type return_type = opts[:return_type] || 'DebAptRepositoryResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(deb_apt_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete an apt repository Trigger an asynchronous delete task
91 92 93 94 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 91 def delete(deb_apt_repository_href, opts = {}) data, _status_code, _headers = delete_with_http_info(deb_apt_repository_href, opts) data end |
#delete_with_http_info(deb_apt_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete an apt repository Trigger an asynchronous delete task
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 101 def delete_with_http_info(deb_apt_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.delete ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.delete" end # resource path local_var_path = '{deb_apt_repository_href}'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginateddebAptRepositoryResponseList
List apt repositorys An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
172 173 174 175 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 172 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginateddebAptRepositoryResponseList, Integer, Hash)>
List apt repositorys An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 201 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.list ...' end allowable_values = ["-description", "-name", "-next_version", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-retain_repo_versions", "-user_hidden", "description", "name", "next_version", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "retain_repo_versions", "user_hidden"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/repositories/deb/apt/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'remote'] = opts[:'remote'] if !opts[:'remote'].nil? query_params[:'retain_repo_versions'] = opts[:'retain_repo_versions'] if !opts[:'retain_repo_versions'].nil? query_params[:'retain_repo_versions__gt'] = opts[:'retain_repo_versions__gt'] if !opts[:'retain_repo_versions__gt'].nil? query_params[:'retain_repo_versions__gte'] = opts[:'retain_repo_versions__gte'] if !opts[:'retain_repo_versions__gte'].nil? query_params[:'retain_repo_versions__isnull'] = opts[:'retain_repo_versions__isnull'] if !opts[:'retain_repo_versions__isnull'].nil? query_params[:'retain_repo_versions__lt'] = opts[:'retain_repo_versions__lt'] if !opts[:'retain_repo_versions__lt'].nil? query_params[:'retain_repo_versions__lte'] = opts[:'retain_repo_versions__lte'] if !opts[:'retain_repo_versions__lte'].nil? query_params[:'retain_repo_versions__ne'] = opts[:'retain_repo_versions__ne'] if !opts[:'retain_repo_versions__ne'].nil? query_params[:'retain_repo_versions__range'] = @api_client.build_collection_param(opts[:'retain_repo_versions__range'], :csv) if !opts[:'retain_repo_versions__range'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'PaginateddebAptRepositoryResponseList' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify(deb_apt_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
274 275 276 277 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 274 def modify(deb_apt_repository_href, repository_add_remove_content, opts = {}) data, _status_code, _headers = modify_with_http_info(deb_apt_repository_href, repository_add_remove_content, opts) data end |
#modify_with_http_info(deb_apt_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 285 def modify_with_http_info(deb_apt_repository_href, repository_add_remove_content, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.modify ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.modify" end # verify the required parameter 'repository_add_remove_content' is set if @api_client.config.client_side_validation && repository_add_remove_content.nil? fail ArgumentError, "Missing the required parameter 'repository_add_remove_content' when calling RepositoriesAptApi.modify" end # resource path local_var_path = '{deb_apt_repository_href}modify/'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(repository_add_remove_content) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#modify\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) ⇒ AsyncOperationResponse
Update an apt repository Trigger an asynchronous partial update task
344 345 346 347 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 344 def partial_update(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) data, _status_code, _headers = partial_update_with_http_info(deb_apt_repository_href, patcheddeb_apt_repository, opts) data end |
#partial_update_with_http_info(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update an apt repository Trigger an asynchronous partial update task
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 355 def partial_update_with_http_info(deb_apt_repository_href, patcheddeb_apt_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.partial_update ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.partial_update" end # verify the required parameter 'patcheddeb_apt_repository' is set if @api_client.config.client_side_validation && patcheddeb_apt_repository.nil? fail ArgumentError, "Missing the required parameter 'patcheddeb_apt_repository' when calling RepositoriesAptApi.partial_update" end # resource path local_var_path = '{deb_apt_repository_href}'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(patcheddeb_apt_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(deb_apt_repository_href, opts = {}) ⇒ DebAptRepositoryResponse
Inspect an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
415 416 417 418 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 415 def read(deb_apt_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(deb_apt_repository_href, opts) data end |
#read_with_http_info(deb_apt_repository_href, opts = {}) ⇒ Array<(DebAptRepositoryResponse, Integer, Hash)>
Inspect an apt repository An AptRepository is the locally stored, Pulp-internal representation of a APT repository. It may be filled with content via synchronization or content upload to create an AptRepositoryVersion.
427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 427 def read_with_http_info(deb_apt_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.read ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.read" end # resource path local_var_path = '{deb_apt_repository_href}'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'DebAptRepositoryResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync(deb_apt_repository_href, apt_repository_sync_url, opts = {}) ⇒ AsyncOperationResponse
Sync from remote Trigger an asynchronous task to sync content
482 483 484 485 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 482 def sync(deb_apt_repository_href, apt_repository_sync_url, opts = {}) data, _status_code, _headers = sync_with_http_info(deb_apt_repository_href, apt_repository_sync_url, opts) data end |
#sync_with_http_info(deb_apt_repository_href, apt_repository_sync_url, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Sync from remote Trigger an asynchronous task to sync content
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 493 def sync_with_http_info(deb_apt_repository_href, apt_repository_sync_url, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.sync ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.sync" end # verify the required parameter 'apt_repository_sync_url' is set if @api_client.config.client_side_validation && apt_repository_sync_url.nil? fail ArgumentError, "Missing the required parameter 'apt_repository_sync_url' when calling RepositoriesAptApi.sync" end # resource path local_var_path = '{deb_apt_repository_href}sync/'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(apt_repository_sync_url) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#sync\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(deb_apt_repository_href, deb_apt_repository, opts = {}) ⇒ AsyncOperationResponse
Update an apt repository Trigger an asynchronous update task
552 553 554 555 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 552 def update(deb_apt_repository_href, deb_apt_repository, opts = {}) data, _status_code, _headers = update_with_http_info(deb_apt_repository_href, deb_apt_repository, opts) data end |
#update_with_http_info(deb_apt_repository_href, deb_apt_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Update an apt repository Trigger an asynchronous update task
563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/pulp_deb_client/api/repositories_apt_api.rb', line 563 def update_with_http_info(deb_apt_repository_href, deb_apt_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesAptApi.update ...' end # verify the required parameter 'deb_apt_repository_href' is set if @api_client.config.client_side_validation && deb_apt_repository_href.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository_href' when calling RepositoriesAptApi.update" end # verify the required parameter 'deb_apt_repository' is set if @api_client.config.client_side_validation && deb_apt_repository.nil? fail ArgumentError, "Missing the required parameter 'deb_apt_repository' when calling RepositoriesAptApi.update" end # resource path local_var_path = '{deb_apt_repository_href}'.sub('{' + 'deb_apt_repository_href' + '}', CGI.escape(deb_apt_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(deb_apt_repository) # return_type return_type = opts[:return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesAptApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |