Class: PulpDebClient::DebAptRepositoryResponse
- Inherits:
-
Object
- Object
- PulpDebClient::DebAptRepositoryResponse
- Defined in:
- lib/pulp_deb_client/models/deb_apt_repository_response.rb
Overview
A Serializer for AptRepository.
Instance Attribute Summary collapse
-
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository.
-
#description ⇒ Object
An optional description.
-
#latest_version_href ⇒ Object
Returns the value of attribute latest_version_href.
-
#name ⇒ Object
A unique name for this repository.
-
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service.
-
#package_signing_fingerprint_release_overrides ⇒ Object
A dictionary of Release distributions and the Package Signing Fingerprints they should use.
-
#package_signing_service ⇒ Object
A reference to an associated package signing service.
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#publish_upstream_release_fields ⇒ Object
Previously, pulp_deb only synced the Release file fields codename and suite, now version, origin, label, and description are also synced.
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#remote ⇒ Object
An optional remote to use by default when syncing.
-
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository.
-
#retain_repo_versions ⇒ Object
Retain X versions of the repository.
-
#signing_service ⇒ Object
A reference to an associated signing service.
-
#signing_service_release_overrides ⇒ Object
A dictionary of Release distributions and the Signing Service URLs they should use.Example: \"/pulp/api/v3/signing-services/433a1f70-c589-4413-a803-c50b842ea9b5/\".
-
#versions_href ⇒ Object
Returns the value of attribute versions_href.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DebAptRepositoryResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DebAptRepositoryResponse
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebAptRepositoryResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebAptRepositoryResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'versions_href') self.versions_href = attributes[:'versions_href'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'latest_version_href') self.latest_version_href = attributes[:'latest_version_href'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'retain_repo_versions') self.retain_repo_versions = attributes[:'retain_repo_versions'] end if attributes.key?(:'retain_checkpoints') self.retain_checkpoints = attributes[:'retain_checkpoints'] end if attributes.key?(:'remote') self.remote = attributes[:'remote'] end if attributes.key?(:'autopublish') self.autopublish = attributes[:'autopublish'] else self.autopublish = false end if attributes.key?(:'publish_upstream_release_fields') self.publish_upstream_release_fields = attributes[:'publish_upstream_release_fields'] end if attributes.key?(:'signing_service') self.signing_service = attributes[:'signing_service'] end if attributes.key?(:'signing_service_release_overrides') if (value = attributes[:'signing_service_release_overrides']).is_a?(Hash) self.signing_service_release_overrides = value end end if attributes.key?(:'package_signing_fingerprint_release_overrides') if (value = attributes[:'package_signing_fingerprint_release_overrides']).is_a?(Hash) self.package_signing_fingerprint_release_overrides = value end end if attributes.key?(:'package_signing_service') self.package_signing_service = attributes[:'package_signing_service'] end if attributes.key?(:'package_signing_fingerprint') self.package_signing_fingerprint = attributes[:'package_signing_fingerprint'] end end |
Instance Attribute Details
#autopublish ⇒ Object
Whether to automatically create publications for new repository versions, and update any distributions pointing to this repository. Will create a standard structured APT publication.
52 53 54 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 52 def autopublish @autopublish end |
#description ⇒ Object
An optional description.
40 41 42 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 40 def description @description end |
#latest_version_href ⇒ Object
Returns the value of attribute latest_version_href.
34 35 36 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 34 def latest_version_href @latest_version_href end |
#name ⇒ Object
A unique name for this repository.
37 38 39 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 37 def name @name end |
#package_signing_fingerprint ⇒ Object
The pubkey fingerprint to be passed to the package signing service. Format: 'v
70 71 72 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 70 def package_signing_fingerprint @package_signing_fingerprint end |
#package_signing_fingerprint_release_overrides ⇒ Object
A dictionary of Release distributions and the Package Signing Fingerprints they should use. Example: \"v4:7FC42CD5F3D8EEC37FC42CD5F3D8EEC3DEADBEEF\"
64 65 66 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 64 def package_signing_fingerprint_release_overrides @package_signing_fingerprint_release_overrides end |
#package_signing_service ⇒ Object
A reference to an associated package signing service.
67 68 69 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 67 def package_signing_service @package_signing_service end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 22 def prn @prn end |
#publish_upstream_release_fields ⇒ Object
Previously, pulp_deb only synced the Release file fields codename and suite, now version, origin, label, and description are also synced. Setting this setting to False will make Pulp revert to the old behaviour of using it's own internal values for the new fields during publish. This is primarily intended to avoid a sudden change in behaviour for existing Pulp repositories, since many Release file field changes need to be accepted by hosts consuming the published repository. The default for new repositories is True.
55 56 57 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 55 def publish_upstream_release_fields @publish_upstream_release_fields end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_labels ⇒ Object
Returns the value of attribute pulp_labels.
32 33 34 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 32 def pulp_labels @pulp_labels end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
28 29 30 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#remote ⇒ Object
An optional remote to use by default when syncing.
49 50 51 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 49 def remote @remote end |
#retain_checkpoints ⇒ Object
Retain X checkpoint publications for the repository. Default is null which retains all checkpoints.
46 47 48 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 46 def retain_checkpoints @retain_checkpoints end |
#retain_repo_versions ⇒ Object
Retain X versions of the repository. Default is null which retains all versions.
43 44 45 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 43 def retain_repo_versions @retain_repo_versions end |
#signing_service ⇒ Object
A reference to an associated signing service. Used if AptPublication.signing_service is not set
58 59 60 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 58 def signing_service @signing_service end |
#signing_service_release_overrides ⇒ Object
A dictionary of Release distributions and the Signing Service URLs they should use.Example: \"/pulp/api/v3/signing-services/433a1f70-c589-4413-a803-c50b842ea9b5/\"
61 62 63 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 61 def signing_service_release_overrides @signing_service_release_overrides end |
#versions_href ⇒ Object
Returns the value of attribute versions_href.
30 31 32 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 30 def versions_href @versions_href end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 372 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpDebClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 98 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 73 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'versions_href' => :'versions_href', :'pulp_labels' => :'pulp_labels', :'latest_version_href' => :'latest_version_href', :'name' => :'name', :'description' => :'description', :'retain_repo_versions' => :'retain_repo_versions', :'retain_checkpoints' => :'retain_checkpoints', :'remote' => :'remote', :'autopublish' => :'autopublish', :'publish_upstream_release_fields' => :'publish_upstream_release_fields', :'signing_service' => :'signing_service', :'signing_service_release_overrides' => :'signing_service_release_overrides', :'package_signing_fingerprint_release_overrides' => :'package_signing_fingerprint_release_overrides', :'package_signing_service' => :'package_signing_service', :'package_signing_fingerprint' => :'package_signing_fingerprint' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 348 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 128 def self.openapi_nullable Set.new([ :'description', :'retain_repo_versions', :'retain_checkpoints', :'remote', :'signing_service', :'package_signing_service', :'package_signing_fingerprint' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 103 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'versions_href' => :'String', :'pulp_labels' => :'Hash<String, String>', :'latest_version_href' => :'String', :'name' => :'String', :'description' => :'String', :'retain_repo_versions' => :'Integer', :'retain_checkpoints' => :'Integer', :'remote' => :'String', :'autopublish' => :'Boolean', :'publish_upstream_release_fields' => :'Boolean', :'signing_service' => :'String', :'signing_service_release_overrides' => :'Hash<String, String>', :'package_signing_fingerprint_release_overrides' => :'Hash<String, String>', :'package_signing_service' => :'String', :'package_signing_fingerprint' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 309 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && versions_href == o.versions_href && pulp_labels == o.pulp_labels && latest_version_href == o.latest_version_href && name == o.name && description == o.description && retain_repo_versions == o.retain_repo_versions && retain_checkpoints == o.retain_checkpoints && remote == o.remote && autopublish == o.autopublish && publish_upstream_release_fields == o.publish_upstream_release_fields && signing_service == o.signing_service && signing_service_release_overrides == o.signing_service_release_overrides && package_signing_fingerprint_release_overrides == o.package_signing_fingerprint_release_overrides && package_signing_service == o.package_signing_service && package_signing_fingerprint == o.package_signing_fingerprint end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 443 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
335 336 337 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 335 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
341 342 343 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 341 def hash [pulp_href, prn, pulp_created, pulp_last_updated, versions_href, pulp_labels, latest_version_href, name, description, retain_repo_versions, retain_checkpoints, remote, autopublish, publish_upstream_release_fields, signing_service, signing_service_release_overrides, package_signing_fingerprint_release_overrides, package_signing_service, package_signing_fingerprint].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 244 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if !@retain_repo_versions.nil? && @retain_repo_versions < 1 invalid_properties.push('invalid value for "retain_repo_versions", must be greater than or equal to 1.') end if !@retain_checkpoints.nil? && @retain_checkpoints < 1 invalid_properties.push('invalid value for "retain_checkpoints", must be greater than or equal to 1.') end if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 invalid_properties.push('invalid value for "package_signing_fingerprint", the character length must be smaller than or equal to 68.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
419 420 421 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 419 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 425 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
413 414 415 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 413 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
268 269 270 271 272 273 274 275 |
# File 'lib/pulp_deb_client/models/deb_apt_repository_response.rb', line 268 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if !@retain_repo_versions.nil? && @retain_repo_versions < 1 return false if !@retain_checkpoints.nil? && @retain_checkpoints < 1 return false if !@package_signing_fingerprint.nil? && @package_signing_fingerprint.to_s.length > 68 true end |