Class: PulpDebClient::DebRelease

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_deb_client/models/deb_release.rb

Overview

A Serializer for Release.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DebRelease

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/pulp_deb_client/models/deb_release.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PulpDebClient::DebRelease` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PulpDebClient::DebRelease`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'repository')
    self.repository = attributes[:'repository']
  end

  if attributes.key?(:'codename')
    self.codename = attributes[:'codename']
  else
    self.codename = nil
  end

  if attributes.key?(:'suite')
    self.suite = attributes[:'suite']
  else
    self.suite = nil
  end

  if attributes.key?(:'distribution')
    self.distribution = attributes[:'distribution']
  else
    self.distribution = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'origin')
    self.origin = attributes[:'origin']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'architectures')
    if (value = attributes[:'architectures']).is_a?(Array)
      self.architectures = value
    end
  end

  if attributes.key?(:'components')
    if (value = attributes[:'components']).is_a?(Array)
      self.components = value
    end
  end
end

Instance Attribute Details

#architecturesObject

Returns the value of attribute architectures.



36
37
38
# File 'lib/pulp_deb_client/models/deb_release.rb', line 36

def architectures
  @architectures
end

#codenameObject

Returns the value of attribute codename.



22
23
24
# File 'lib/pulp_deb_client/models/deb_release.rb', line 22

def codename
  @codename
end

#componentsObject

Returns the value of attribute components.



38
39
40
# File 'lib/pulp_deb_client/models/deb_release.rb', line 38

def components
  @components
end

#descriptionObject

Returns the value of attribute description.



34
35
36
# File 'lib/pulp_deb_client/models/deb_release.rb', line 34

def description
  @description
end

#distributionObject

Returns the value of attribute distribution.



26
27
28
# File 'lib/pulp_deb_client/models/deb_release.rb', line 26

def distribution
  @distribution
end

#labelObject

Returns the value of attribute label.



32
33
34
# File 'lib/pulp_deb_client/models/deb_release.rb', line 32

def label
  @label
end

#originObject

Returns the value of attribute origin.



30
31
32
# File 'lib/pulp_deb_client/models/deb_release.rb', line 30

def origin
  @origin
end

#repositoryObject

A URI of a repository the new content unit should be associated with.



20
21
22
# File 'lib/pulp_deb_client/models/deb_release.rb', line 20

def repository
  @repository
end

#suiteObject

Returns the value of attribute suite.



24
25
26
# File 'lib/pulp_deb_client/models/deb_release.rb', line 24

def suite
  @suite
end

#versionObject

Returns the value of attribute version.



28
29
30
# File 'lib/pulp_deb_client/models/deb_release.rb', line 28

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/pulp_deb_client/models/deb_release.rb', line 356

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = PulpDebClient.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/pulp_deb_client/models/deb_release.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/pulp_deb_client/models/deb_release.rb', line 41

def self.attribute_map
  {
    :'repository' => :'repository',
    :'codename' => :'codename',
    :'suite' => :'suite',
    :'distribution' => :'distribution',
    :'version' => :'version',
    :'origin' => :'origin',
    :'label' => :'label',
    :'description' => :'description',
    :'architectures' => :'architectures',
    :'components' => :'components'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/pulp_deb_client/models/deb_release.rb', line 332

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
83
84
85
# File 'lib/pulp_deb_client/models/deb_release.rb', line 78

def self.openapi_nullable
  Set.new([
    :'version',
    :'origin',
    :'label',
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/pulp_deb_client/models/deb_release.rb', line 62

def self.openapi_types
  {
    :'repository' => :'String',
    :'codename' => :'String',
    :'suite' => :'String',
    :'distribution' => :'String',
    :'version' => :'String',
    :'origin' => :'String',
    :'label' => :'String',
    :'description' => :'String',
    :'architectures' => :'Array<String>',
    :'components' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/pulp_deb_client/models/deb_release.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      repository == o.repository &&
      codename == o.codename &&
      suite == o.suite &&
      distribution == o.distribution &&
      version == o.version &&
      origin == o.origin &&
      label == o.label &&
      description == o.description &&
      architectures == o.architectures &&
      components == o.components
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/pulp_deb_client/models/deb_release.rb', line 427

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


319
320
321
# File 'lib/pulp_deb_client/models/deb_release.rb', line 319

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



325
326
327
# File 'lib/pulp_deb_client/models/deb_release.rb', line 325

def hash
  [repository, codename, suite, distribution, version, origin, label, description, architectures, components].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/pulp_deb_client/models/deb_release.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @codename.nil?
    invalid_properties.push('invalid value for "codename", codename cannot be nil.')
  end

  if @codename.to_s.length < 1
    invalid_properties.push('invalid value for "codename", the character length must be great than or equal to 1.')
  end

  if @suite.nil?
    invalid_properties.push('invalid value for "suite", suite cannot be nil.')
  end

  if @suite.to_s.length < 1
    invalid_properties.push('invalid value for "suite", the character length must be great than or equal to 1.')
  end

  if @distribution.nil?
    invalid_properties.push('invalid value for "distribution", distribution cannot be nil.')
  end

  if @distribution.to_s.length < 1
    invalid_properties.push('invalid value for "distribution", the character length must be great than or equal to 1.')
  end

  if !@version.nil? && @version.to_s.length < 1
    invalid_properties.push('invalid value for "version", the character length must be great than or equal to 1.')
  end

  if !@origin.nil? && @origin.to_s.length < 1
    invalid_properties.push('invalid value for "origin", the character length must be great than or equal to 1.')
  end

  if !@label.nil? && @label.to_s.length < 1
    invalid_properties.push('invalid value for "label", the character length must be great than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length < 1
    invalid_properties.push('invalid value for "description", the character length must be great than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



403
404
405
# File 'lib/pulp_deb_client/models/deb_release.rb', line 403

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/pulp_deb_client/models/deb_release.rb', line 409

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



397
398
399
# File 'lib/pulp_deb_client/models/deb_release.rb', line 397

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/pulp_deb_client/models/deb_release.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @codename.nil?
  return false if @codename.to_s.length < 1
  return false if @suite.nil?
  return false if @suite.to_s.length < 1
  return false if @distribution.nil?
  return false if @distribution.to_s.length < 1
  return false if !@version.nil? && @version.to_s.length < 1
  return false if !@origin.nil? && @origin.to_s.length < 1
  return false if !@label.nil? && @label.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length < 1
  true
end